Welcome to TorchKGE's documentation!
======================================

.. include:: readme.rst

.. toctree::
   :maxdepth: 2
   :caption: Tutorials:

   tutorials/transe

.. toctree::
   :maxdepth: 1
   :caption: Reference:

   reference/models
   reference/sampling
   reference/evaluation
   reference/data
   reference/utils


.. toctree::
   :maxdepth: 1
   :caption: Installation:

   installation

.. toctree::
   :maxdepth: 1
   :caption: About:

   contributing
   authors
   history
